
# Analysis from: Testosterone-mediated behavior shapes the emergent properties of social networks
# Roslyn Dakin, Ignacio T. Moore, Brent M. Horton, Ben J. Vernasco, and T. Brandt Ryder
# Revised December 2019

# This script performs the node-label permutation of the social networks 

library(dplyr)
library(igraph)
library(assortnet)
library(bipartite)
library(lme4)
library(lmerTest)
library(visreg)

# Get social interaction data:
ally <- read.csv('ally_with_pre-net_perm.csv', stringsAsFactors=F); head(ally); dim(ally)

# Get data on social network properties:
net.prop <- read.csv('network_properties.csv', stringsAsFactors=F); head(net.prop); dim(net.prop) # 86. Each row is a social network (recording session)

# Testosterone phenotype from Ryder et al. 2020:
Tphen <- read.csv('T_phenotype.csv', stringsAsFactors=F)[,-1]; head(Tphen); dim(Tphen) # 524
net.prop$meanT_TH <- NA
net.prop$meanT_FL <- NA
net.prop$assort_strength <- NA
net.prop$assort_degree <- NA
net.prop$specialization <- NA
net.prop$stability2 <- NA
net.prop$hetero.int <- NA
net.prop$terr.terr.int <- NA
net.prop$floa.floa.int <- NA

# Get the weighted average collective testosterone for each social network:
for(i in 1:nrow(net.prop)){ 
	yr <- net.prop$studyyear[i]
	lk <- net.prop$Lek[i]
	dl <- net.prop$DL[i]
	temp <- subset(ally, studyyear==yr & Lek==lk & DL==dl)
	temp <- data.frame(table(temp$Color1))
	ttemp <- unique(subset(Tphen, ID %in% temp$Var1 & studyyear==yr)[,c('ID','Status','meanT')])
	temp$test <- ttemp$meanT[match(temp$Var1, ttemp$ID)]
	temp$Status <- ttemp$Status[match(temp$Var1, ttemp$ID)]
	tempT <- subset(temp, Status=='terr')
	tempF <- subset(temp, Status=='floa')
	net.prop$meanT_TH[i] <- weighted.mean(tempT$test, w=tempT$Freq, na.rm=T)	
	net.prop$meanT_FL[i] <- weighted.mean(tempF$test, w=tempF$Freq, na.rm=T)
}

# Get daily behaviors:
phen <- read.csv('daily_social_phenotypes_4.csv', stringsAsFactors=F); head(phen); dim(phen) # 5,039
phen$date <- as.Date(phen$date, format='%m/%d/%y')

# Calculate assortment and specialization:
for(i in 1:nrow(net.prop)){
	yr <- net.prop$studyyear[i]
	lk <- net.prop$Lek[i]
	dl <- net.prop$DL[i]	
	g1.0 <- subset(ally, studyyear==yr & Lek==lk & DL==dl)[,c('Color1','Color2','sitefix','date')]

	g1a <- unique(g1.0[,c('Color1','Color2')]) # duplicate interactions
	g1a <- subset(g1a, Color1<Color2) # removes duplicates
	temp <- summarize(group_by(g1.0, Color1, Color2), n=n())
	g1a$raw.weight <- temp$n[match(paste(g1a$Color1, g1a$Color2),  paste(temp$Color1, temp$Color2))]
	ggg <- graph.data.frame(data.frame(Color1=g1a$Color1, Color2=g1a$Color2, weight=g1a$raw.weight), directed=F) # Build the network
	
	# Get stability:
	
	g1.0_next <- subset(ally, studyyear==yr & Lek==lk & DL==dl+1)[,c('Color1','Color2','sitefix','date')]
	g1a_next <- unique(g1.0_next[,c('Color1', 'Color2')]) # duplicate interactions
	g1a_next <- subset(g1a_next, Color1<Color2) # remove duplicates
	temp_next <- summarize(group_by(g1.0_next, Color1, Color2), n=n())
	g1a_next$raw.weight <- temp_next$n[match(paste(g1a_next$Color1, g1a_next$Color2), paste(temp_next$Color1, temp_next$Color2))]
	ggg_next <- graph.data.frame(data.frame(Color1=g1a_next$Color1, Color2=g1a_next$Color2, weight=g1a_next$raw.weight), directed=F)
	
	allms <- intersect(names(V(ggg_next)), names(V(ggg)))
	
	if(nrow(g1a_next)>0 & nrow(g1a)>0){
		bip_P <- as.matrix(as_adj(ggg, sparse=F, attr='weight'))
		bip_P_next <- as.matrix(as_adj(ggg_next, sparse=F, attr='weight'))
		
		threshold <- 6
		bip_P[bip_P< threshold] <- 0 # threshhold
		bip_P_next[bip_P_next< threshold] <- 0 # threshold
		
		bip_P <- bip_P[allms, allms]
		bip_P_next <- bip_P_next[allms, allms]
		checkmat <- bip_P>0 & bip_P_next>0
		anymat <- bip_P>0 | bip_P_next>0
		net.prop$stability2[i] <- sum(checkmat[upper.tri(checkmat)])/sum(anymat[upper.tri(anymat)])
	}
	
	# Get social specialization:
	ggg2 <- as_adj(ggg, sparse=F, attr='weight') # Adjacency matrix
	cnames <- names(V(ggg))[names(V(ggg)) %in% unique(g1.0$sitefix)]
	rnames <- names(V(ggg))[!names(V(ggg)) %in% unique(g1.0$sitefix)]
	bip <- as.matrix(ggg2[rnames, cnames], nrow=length(rnames), ncol=length(cnames)) # Trimmed
	if(nrow(bip)>1 & ncol(bip)>1 & sum(bip)>0){
		net.prop$specialization[i] <- H2fun(bip)[1]
	}
	
	net.prop$hetero.int[i] <- sum(bip)/sum(E(ggg)$weight)
	net.prop$terr.terr.int[i] <- sum(as.matrix(ggg2[cnames, cnames], nrow=length(cnames), ncol=length(cnames)))/2/sum(E(ggg)$weight)
	net.prop$floa.floa.int[i] <- sum(as.matrix(ggg2[rnames, rnames], nrow=length(rnames), ncol=length(rnames)))/2/sum(E(ggg)$weight)

	# Behavioral assortment, exclude daily behaviors within 10 days of any implant surgeries:
	temp <- subset(phen, (!timesincemanip %in% c(1:10)) & studyyear==yr & ID1 %in% names(V(ggg)) & date %in% as.Date(unique(g1.0$date)))[,c('ID1','date','pingsL','num.intL','num.partL','Status')] 
	temp <- summarize(group_by(temp, ID1, Status), effort=mean(pingsL), strength=mean(num.intL), degree=mean(num.partL))
	temp <- temp[match(names(V(ggg)), temp$ID1),] # sort
	temp$ID1 <- names(V(ggg))
	temp$Status[is.na(temp$Status)] <- unique(subset(phen, studyyear==yr)[,c('ID1','Status')])$Status[match(temp$ID1[is.na(temp$Status)], 	unique(subset(phen, studyyear==yr)[,c('ID1','Status')])$ID1)]

	ggg3 <- as_adj(igraph::delete.vertices(ggg, temp$ID1[is.na(temp$strength)]), sparse=F, attr='weight') 	
	net.prop$assort_strength[i] <- assortment.continuous(ggg3, temp[!is.na(temp$strength),]$strength, weighted=TRUE)$r
	net.prop$assort_degree[i] <- assortment.continuous(ggg3, temp[!is.na(temp$degree),]$degree, weighted=TRUE)$r

	# Status assortment:
	net.prop$assort_status[i] <- assortment.discrete(ggg2, temp$Status, weighted=T)$r # Get status assortment, weighted

	print(i)
}
net.prop$behavASSORT <- (rowMeans(net.prop[,c('assort_strength','assort_degree')], na.rm=T))








# Node-label permutation. Permute the networks, node label. Note that it has to be across classes, or else spec. is unchanged:

null.coef <- data.frame(spec=rep(NA, 1000), stab=NA, assort=NA); head(null.coef); dim(null.coef)
net.prop.null <- vector('list', length=1000)
for(i in 1:1000){
	net.prop.null[[i]] <- net.prop[,c('studyyear','Lek','yday.adj','hours.per','Tplus','nbird','meanT_TH','meanT_FL','assort_status','specialization','stability2','behavASSORT')]
}

# Generate the node-label permuted datasets:
for(i in 1:1000){
	Tstart <- unique(subset(Tphen)[,c('ID','Status','meanT')]); Tstart$permute <- Tstart$ID
	set.seed(i)
	
	for(j in 1:86){
		yr <- net.prop$studyyear[j]
		lk <- net.prop$Lek[j]
		dl <- net.prop$DL[j]	
		g1.0 <- subset(ally, studyyear==yr & Lek==lk & DL==dl)[,c('Color1','Color2','sitefix','date')]

		g1a <- unique(g1.0[,c('Color1','Color2')]) # duplicate interactions
		g1a <- subset(g1a, Color1<Color2) # removes duplicates
		temp <- summarize(group_by(g1.0, Color1, Color2), n=n())
		g1a$raw.weight <- temp$n[match(paste(g1a$Color1, g1a$Color2),  paste(temp$Color1, temp$Color2))]
		ggg <- graph.data.frame(data.frame(Color1=g1a$Color1, Color2=g1a$Color2, weight=g1a$raw.weight), directed=F) # Build the network
		
		gggR <- ggg # gggR will be permuted network
		vertex_attr(gggR)$name <- sample(vertex_attr(gggR)$name) # Node-label permutation
				
		xtemp <- data.frame(Var1=names(igraph::strength(gggR)), freq=igraph::strength(gggR)) # Testosterone
		ttemp <- unique(subset(Tstart, permute %in% xtemp$Var1)[,c('permute','Status','meanT')])
		xtemp$test <- ttemp$meanT[match(xtemp$Var1, ttemp$permute)]
		xtemp$Status <- ttemp$Status[match(xtemp$Var1, ttemp$permute)]
		tempF <- subset(xtemp, Status=='floa')
		tempT <- subset(xtemp, Status=='terr')
		net.prop.null[[i]]$meanT_FL[j] <- weighted.mean(tempF$test, w=tempF$freq, na.rm=T) 
		net.prop.null[[i]]$meanT_TH[j] <- weighted.mean(tempT$test, w=tempT$freq, na.rm=T)
		
		# Specialization:
		ggg2 <- as_adj(gggR, sparse=F, attr='weight') # Adjacency matrix
		cnames <- names(V(gggR))[names(V(gggR)) %in% unique(g1.0$sitefix)]
		rnames <- names(V(gggR))[!names(V(gggR)) %in% unique(g1.0$sitefix)]
		bip <- as.matrix(ggg2[rnames, cnames], nrow=length(rnames), ncol=length(cnames)) # Trimmed
		if(nrow(bip)>1 & ncol(bip)>1 & sum(bip)>0){
			net.prop.null[[i]]$specialization[j] <- H2fun(bip)[1]
		} else {
			net.prop.null[[i]]$specialization[j] <- NA
		}

		# Behavioral assortment:
		temp <- subset(phen, (!timesincemanip %in% c(1:10)) & studyyear==yr & ID1 %in% names(V(gggR)) & date %in% as.Date(unique(g1.0$date)))[,c('ID1','date','pingsL','num.intL','num.partL','Status')] 
		temp <- summarize(group_by(temp, ID1, Status), effort=mean(pingsL), strength=mean(num.intL), degree=mean(num.partL))
		temp <- temp[match(names(V(gggR)), temp$ID1),] # sort
		temp$ID1 <- names(V(gggR))
		temp$Status[is.na(temp$Status)] <- unique(subset(phen, studyyear==yr)[,c('ID1','Status')])$Status[match(temp$ID1[is.na(temp$Status)], 	unique(subset(phen, studyyear==yr)[,c('ID1','Status')])$ID1)]

		ggg3 <- as_adj(igraph::delete.vertices(gggR, temp$ID1[is.na(temp$strength)]), sparse=F, attr='weight') 	
		net.prop.null[[i]]$assort_strength[j] <- assortment.continuous(ggg3, temp[!is.na(temp$strength),]$strength, weighted=TRUE)$r
		net.prop.null[[i]]$assort_degree[j] <- assortment.continuous(ggg3, temp[!is.na(temp$degree),]$degree, weighted=TRUE)$r

		# Status assortment:
		net.prop.null[[i]]$assort_status[j] <- assortment.discrete(ggg2, temp$Status, weighted=T)$r # Get status assortment, weighted

		# Stability:		
		bip <- (as.matrix(get.adjacency(gggR, type='both', attr='weight'))) # whole network	
		xxx <- subset(ally, studyyear==yr & Lek==lk & DL==dl+1)[,c('Color1','Color2','sitefix','date')]
		if(nrow(xxx)>0){
			bip1 <- bip
			xxx1a <- unique(xxx[,c('Color1','Color2')]) # duplicate interactions
			xxx1a <- subset(xxx1a, Color1<Color2) # removes duplicates
			temp <- summarize(group_by(xxx, Color1, Color2), n=n())
			xxx1a$raw.weight <- temp$n[match(paste(xxx1a$Color1, xxx1a$Color2),  paste(temp$Color1, temp$Color2))]
			ggg.next <- graph.data.frame(data.frame(Color1=xxx1a$Color1, Color2=xxx1a$Color2, weight=xxx1a$raw.weight), directed=F) # Build the network
			bip2 <- (as.matrix(get.adjacency(ggg.next, type='both', attr='weight')))
	
			bip[bip<6] <- 0
			bip2[bip2<6] <- 0
			if( any(!rownames(bip) %in% rownames(bip2)) | any(!rownames(bip2) %in% rownames(bip)) ){
				newnames <- intersect(rownames(bip), rownames(bip2))
				bip <- bip[newnames, newnames]
				bip2 <- bip2[newnames, newnames]
			}
			
			# Intersection/union:
			net.prop.null[[i]]$stability2[j] <- sum( (bip2>0)[upper.tri(bip2)] & (bip>0)[upper.tri(bip)] ) / sum( pmax((bip2>0)[upper.tri(bip2)], (bip>0)[upper.tri(bip)]) )

		}	
	}
	net.prop.null[[i]]$behavASSORT <- (rowMeans(net.prop.null[[i]][,c('assort_strength','assort_degree')], na.rm=T))
	print(i)
}

# Fit models:
for(i in 1:1000){
	mod2 <- (lmer(specialization ~ studyyear + yday.adj + log(nbird) + meanT_TH + hours.per + (1|Lek), data=subset(net.prop.null[[i]], Tplus==0), REML=T))
	null.coef$spec[i] <- fixef(mod2)['meanT_TH'] # -0.261774

	mod2 <- (lmer(stability2 ~ studyyear + yday.adj + log(nbird) + meanT_TH + hours.per + (1|Lek), data=subset(net.prop.null[[i]], Tplus==0), REML=T))
	null.coef$stab[i] <- fixef(mod2)['meanT_TH'] # -0.223957

	mod1 <- (lmer(behavASSORT ~ studyyear + yday.adj + log(nbird) + meanT_FL + meanT_TH + assort_status + hours.per + (1|Lek), data=subset(net.prop.null[[i]], Tplus==0), REML=T))
	null.coef$assort[i] <- fixef(mod1)['meanT_TH'] # -0.225901
	print(i)
}

# Plot the distribution of slopes in the null analysis as compared to the observed data:
dev.new(width=2, height=5)
par(mfrow=c(3,1), mar=c(3,3,3,0.2), las=1, bty='l')

h <- hist(null.coef$spec,  xlim=c(-0.5,0.5), breaks=20, main='Specialization', cex.main=0.75, col=rgb(0,0,0,0.1), border=NA)
x <- density(null.coef$spec, na.rm=T)
x$y <- x$y*max(h$counts)/max(x$y)
points(x$y ~ x$x, type='l')
quantile(null.coef$spec, c(0.025), na.rm=T)
sum(null.coef$spec < -0.261774)/1000 # p = 0.02
abline(v=-0.261774, lty=3)

h <- hist(null.coef$stab,  xlim=c(-0.5,0.5), breaks=10, main='Stability', cex.main=0.75, col=rgb(0,0,0,0.1), border=NA)
x <- density(null.coef$stab, na.rm=T)
x$y <- x$y*max(h$counts)/max(x$y)
points(x$y ~ x$x, type='l')
quantile(null.coef$stab, c(0.025), na.rm=T)
sum(null.coef$stab < -0.223957)/1000 # p = 0.001
abline(v=-0.223957, lty=3)

h <- hist(null.coef$assort,  xlim=c(-0.5,0.5), breaks=15, main='Assortment', cex.main=0.75, col=rgb(0,0,0,0.1), border=NA)
x <- density(null.coef$assort, na.rm=T)
x$y <- x$y*max(h$counts)/max(x$y)
points(x$y ~ x$x, type='l')
quantile(null.coef$assort, c(0.025), na.rm=T)
sum(null.coef$assort < -0.225901)/1000 # p = 0.005
abline(v=-0.225901, lty=3)

# save(net.prop.null, null.coef, file='node-label_permutation.RData')


