
# Analysis from: Testosterone-mediated behavior shapes the emergent properties of social networks
# Roslyn Dakin, Ignacio T. Moore, Brent M. Horton, Ben J. Vernasco, and T. Brandt Ryder
# Revised December 2019

# This script compiles the data, performs the main statistical analysis of network properties

library(dplyr)
library(igraph)
library(assortnet)
library(bipartite)
library(lme4)
library(lmerTest)
library(visreg)
library(tidyr)
library(plotfunctions)

# Get social interaction data:

ally <- read.csv('ally_with_pre-net_perm.csv', stringsAsFactors=F); head(ally); dim(ally)
allpermdyads <- read.csv('allpermdyads.csv', stringsAsFactors=F); head(allpermdyads)

head(ally)
reality.check <- as.data.frame(table(paste(ally$studyyear, ally$Lek, ally$DL), ally$compare_perm))
reality.check <- tidyr::spread(reality.check, Var2, Freq)
names(reality.check) <- c('ID', 'Below_exp', 'Above_exp'); head(reality.check)
reality.check$proportion <- reality.check$Below_exp/rowSums(reality.check[,c('Below_exp','Above_exp')])
summary(reality.check$proportion*100) 
par(mfrow=c(1,1), mar=c(4,4,0.2,0.2))
hist(reality.check$proportion*100, breaks=60, main='', xlab='% Below expected', las=1, xlim=c(0,100))
abline(v=mean(reality.check$proportion)*100, lty=3); mean(reality.check$proportion)*100

reality.check2 <- summarize(group_by(ally, ID), freq=n(), Compare=mean(as.numeric(compare_perm)))
head(reality.check2)

reality.check2 <- merge(reality.check2, allpermdyads, by.x='ID', by.y='dyadC', all.x=T, all.y=F)
reality.check2$avg.freq[is.na(reality.check2$avg.freq)] <- 0

# Note that reality.check2 is duplicated, so any descriptive statistics must only use 1/2 of it.
dim(reality.check2) # 5,996
reality.check2$ID <- gsub('Al Rio', 'Al-Rio', reality.check2$ID)
reality.check2$sortID <- reality.check2$ID
reality.check2$sortID <- stringr::str_split(reality.check2$sortID, ' ', simplify=T)[,4]
reality.check2$b1 <- stringr::str_split(reality.check2$sortID, '_', simplify=T)[,1]
reality.check2$b2 <- stringr::str_split(reality.check2$sortID, '_', simplify=T)[,2]
reality.check2$border <- ifelse(reality.check2$b1 < reality.check2$b2, paste(reality.check2$b1, reality.check2$b2, sep='_'), paste(reality.check2$b2, reality.check2$b1, sep='_'))
reality.check2$sortID <- paste(do.call(paste, data.frame(stringr::str_split(reality.check2$ID, ' ', simplify=T)[,1:3])), reality.check2$border, sep=' ')
sum(!duplicated(reality.check2$sortID))*2 # ok.

reality.check2$var <- round(reality.check2$freq, -1)
reality.check2$var[reality.check2$var>200] <- 200
p.summ <- summarize(group_by(reality.check2[!duplicated(reality.check2$sortID),], var), avg=mean(avg.freq), lower=quantile(avg.freq, 0.025), upper=quantile(avg.freq, 0.975), lq=quantile(avg.freq, 0.25), uq=quantile(avg.freq,0.75), max=max(avg.freq), min=min(avg.freq))

par(las=1, bty='l', mar=c(4,4,1,1), mgp=c(2,0.5,0), mfrow=c(2,2))

plot(avg ~  c(var+5), p.summ, pch=16, xlab='Actual occurrence (# times)', ylab='Permutation occurrence (# times)', xlim=c(0,210), ylim=c(0,40), xaxt='n', type='n', yaxt='n')
for(i in 1:21){
	temp <- subset(p.summ, var==i*10 - 10)
	segments(x0=temp$var+5, y0=temp$min, y1=temp$max, lwd=0.4)
	polygon(x=c((temp$var)+5-4, (temp$var)+5+4, (temp$var)+5+4, (temp$var)+5-4), y=c(temp$lq, temp$lq, temp$uq, temp$uq), col='light grey')
	segments(x0=(temp$var)+5-4, x1=(temp$var)+5+4, y0=temp$avg)
	segments(x0=(temp$var)+5-4, x1=(temp$var)+5+4, y0=temp$lq)
	segments(x0=(temp$var)+5-4, x1=(temp$var)+5+4, y0=temp$uq)
	segments(x0=(temp$var)+5-2, x1=(temp$var)+5+2, y0=temp$max, lwd=0.4)
	segments(x0=(temp$var)+5-2, x1=(temp$var)+5+2, y0=temp$min, lwd=0.4)
}
axis(2, at=seq(0,40,by=10), cex.axis=0.5)
axis(1, at=seq(5,205,by=10), cex.axis=0.5, labels=paste(seq(0,200,by=10),'-',seq(10,210,by=10), sep=''), las=2)
abline(a=0,b=1,lty=3)
# change axis to 1-10 and >200

sum(reality.check2[!duplicated(reality.check2$sortID),]$Compare)
dim(reality.check2[!duplicated(reality.check2$sortID),])
(2998-2840)/2998 # only 158 out of 2998, or 5% of observed partnerships, occur less than expected in pre-network perm


# Get data on social network properties:
net.prop <- read.csv('network_properties.csv', stringsAsFactors=F); head(net.prop); dim(net.prop) # 86. Each row is a social network (recording session)

# Testosterone phenotype from Ryder et al. 2020:
Tphen <- read.csv('T_phenotype.csv', stringsAsFactors=F)[,-1]; head(Tphen); dim(Tphen) # 524
net.prop$meanT_TH <- NA
net.prop$meanT_FL <- NA
net.prop$assort_strength <- NA
net.prop$assort_degree <- NA
net.prop$specialization <- NA
net.prop$stability2 <- NA
net.prop$hetero.int <- NA
net.prop$terr.terr.int <- NA
net.prop$floa.floa.int <- NA

# Get the weighted average collective testosterone for each social network:
for(i in 1:nrow(net.prop)){ 
	yr <- net.prop$studyyear[i]
	lk <- net.prop$Lek[i]
	dl <- net.prop$DL[i]
	temp <- subset(ally, studyyear==yr & Lek==lk & DL==dl)
	temp <- data.frame(table(temp$Color1))
	ttemp <- unique(subset(Tphen, ID %in% temp$Var1 & studyyear==yr)[,c('ID','Status','meanT')])
	temp$test <- ttemp$meanT[match(temp$Var1, ttemp$ID)]
	temp$Status <- ttemp$Status[match(temp$Var1, ttemp$ID)]
	tempT <- subset(temp, Status=='terr')
	tempF <- subset(temp, Status=='floa')
	net.prop$meanT_TH[i] <- weighted.mean(tempT$test, w=tempT$Freq, na.rm=T)	
	net.prop$meanT_FL[i] <- weighted.mean(tempF$test, w=tempF$Freq, na.rm=T)
}

# Get daily behaviors:
phen <- read.csv('daily_social_phenotypes_4.csv', stringsAsFactors=F); head(phen); dim(phen) # 5,039
phen$date <- as.Date(phen$date, format='%m/%d/%y')

# Calculate assortment and specialization:
for(i in 1:nrow(net.prop)){
	yr <- net.prop$studyyear[i]
	lk <- net.prop$Lek[i]
	dl <- net.prop$DL[i]	
	g1.0 <- subset(ally, studyyear==yr & Lek==lk & DL==dl)[,c('Color1','Color2','sitefix','date')]

	g1a <- unique(g1.0[,c('Color1','Color2')]) # duplicate interactions
	g1a <- subset(g1a, Color1<Color2) # removes duplicates
	temp <- summarize(group_by(g1.0, Color1, Color2), n=n())
	g1a$raw.weight <- temp$n[match(paste(g1a$Color1, g1a$Color2),  paste(temp$Color1, temp$Color2))]
	ggg <- graph.data.frame(data.frame(Color1=g1a$Color1, Color2=g1a$Color2, weight=g1a$raw.weight), directed=F) # Build the network
	
	# Get stability:
	
	g1.0_next <- subset(ally, studyyear==yr & Lek==lk & DL==dl+1)[,c('Color1','Color2','sitefix','date')]
	g1a_next <- unique(g1.0_next[,c('Color1', 'Color2')]) # duplicate interactions
	g1a_next <- subset(g1a_next, Color1<Color2) # remove duplicates
	temp_next <- summarize(group_by(g1.0_next, Color1, Color2), n=n())
	g1a_next$raw.weight <- temp_next$n[match(paste(g1a_next$Color1, g1a_next$Color2), paste(temp_next$Color1, temp_next$Color2))]
	ggg_next <- graph.data.frame(data.frame(Color1=g1a_next$Color1, Color2=g1a_next$Color2, weight=g1a_next$raw.weight), directed=F)
	
	allms <- intersect(names(V(ggg_next)), names(V(ggg)))
	
	if(nrow(g1a_next)>0 & nrow(g1a)>0){
		bip_P <- as.matrix(as_adj(ggg, sparse=F, attr='weight'))
		bip_P_next <- as.matrix(as_adj(ggg_next, sparse=F, attr='weight'))
		
		threshold <- 6
		bip_P[bip_P< threshold] <- 0 # threshhold
		bip_P_next[bip_P_next< threshold] <- 0 # threshold
		
		bip_P <- bip_P[allms, allms]
		bip_P_next <- bip_P_next[allms, allms]
		checkmat <- bip_P>0 & bip_P_next>0
		anymat <- bip_P>0 | bip_P_next>0
		net.prop$stability2[i] <- sum(checkmat[upper.tri(checkmat)])/sum(anymat[upper.tri(anymat)])
	}
	
	# Get social specialization:
	ggg2 <- as_adj(ggg, sparse=F, attr='weight') # Adjacency matrix
	cnames <- names(V(ggg))[names(V(ggg)) %in% unique(g1.0$sitefix)]
	rnames <- names(V(ggg))[!names(V(ggg)) %in% unique(g1.0$sitefix)]
	bip <- as.matrix(ggg2[rnames, cnames], nrow=length(rnames), ncol=length(cnames)) # Trimmed
	if(nrow(bip)>1 & ncol(bip)>1 & sum(bip)>0){
		net.prop$specialization[i] <- H2fun(bip)[1]
	}
	
	net.prop$hetero.int[i] <- sum(bip)/sum(E(ggg)$weight)
	net.prop$terr.terr.int[i] <- sum(as.matrix(ggg2[cnames, cnames], nrow=length(cnames), ncol=length(cnames)))/2/sum(E(ggg)$weight)
	net.prop$floa.floa.int[i] <- sum(as.matrix(ggg2[rnames, rnames], nrow=length(rnames), ncol=length(rnames)))/2/sum(E(ggg)$weight)

	# Behavioral assortment, exclude daily behaviors within 10 days of any implant surgeries:
	temp <- subset(phen, (!timesincemanip %in% c(1:10)) & studyyear==yr & ID1 %in% names(V(ggg)) & date %in% as.Date(unique(g1.0$date)))[,c('ID1','date','pingsL','num.intL','num.partL','Status')] 
	temp <- summarize(group_by(temp, ID1, Status), effort=mean(pingsL), strength=mean(num.intL), degree=mean(num.partL))
	temp <- temp[match(names(V(ggg)), temp$ID1),] # sort
	temp$ID1 <- names(V(ggg))
	temp$Status[is.na(temp$Status)] <- unique(subset(phen, studyyear==yr)[,c('ID1','Status')])$Status[match(temp$ID1[is.na(temp$Status)], 	unique(subset(phen, studyyear==yr)[,c('ID1','Status')])$ID1)]

	ggg3 <- as_adj(igraph::delete.vertices(ggg, temp$ID1[is.na(temp$strength)]), sparse=F, attr='weight') 	
	net.prop$assort_strength[i] <- assortment.continuous(ggg3, temp[!is.na(temp$strength),]$strength, weighted=TRUE)$r
	net.prop$assort_degree[i] <- assortment.continuous(ggg3, temp[!is.na(temp$degree),]$degree, weighted=TRUE)$r

	# Status assortment:
	net.prop$assort_status[i] <- assortment.discrete(ggg2, temp$Status, weighted=T)$r # Get status assortment, weighted

	print(i)
}
net.prop$behavASSORT <- (rowMeans(net.prop[,c('assort_strength','assort_degree')], na.rm=T))


# Fit and compare candidate models:

# Social specialization
mod1 <- (lmer(specialization ~ studyyear + yday.adj + log(nbird) + meanT_FL + meanT_TH + hours.per + (1|Lek), data=subset(net.prop, Tplus==0), REML=F))
mod2 <- (lmer(specialization ~ studyyear + yday.adj + log(nbird) + meanT_TH + hours.per + (1|Lek), data=subset(net.prop, Tplus==0), REML=F))
mod3 <- (lmer(specialization ~ studyyear + yday.adj + log(nbird) + meanT_FL + hours.per + (1|Lek), data=subset(net.prop, Tplus==0), REML=F))
mod4 <- (lmer(specialization ~ studyyear + yday.adj + log(nbird) + hours.per + (1|Lek), data=subset(net.prop, Tplus==0), REML=F))
AIC(mod1, mod2, mod3, mod4)[with(AIC(mod1, mod2, mod3, mod4), order(AIC)),]
summary(update(mod2, REML=T)) # 70 obs. of 11 leks (80 where Tplus==0, 10 NAs for specialization)

# Stability
mod1 <- (lmer(stability2 ~ studyyear + yday.adj + log(nbird) + meanT_FL + meanT_TH + hours.per + (1|Lek), data=subset(net.prop, Tplus==0), REML=F))
mod2 <- (lmer(stability2 ~ studyyear + yday.adj + log(nbird) + meanT_TH + hours.per + (1|Lek), data=subset(net.prop, Tplus==0), REML=F))
mod3 <- (lmer(stability2 ~ studyyear + yday.adj + log(nbird) + meanT_FL + hours.per + (1|Lek), data=subset(net.prop, Tplus==0), REML=F))
mod4 <- (lmer(stability2 ~ studyyear + yday.adj + log(nbird) + hours.per + (1|Lek), data=subset(net.prop, Tplus==0), REML=F))
AIC(mod1, mod2, mod3, mod4)[with(AIC(mod1, mod2, mod3, mod4), order(AIC)),]
summary(update(mod2, REML=T)) # n = 54 obs. of 11 leks (80 where Tplus==0, 26 NAs for stability)

# Behavioral assortment
mod1 <- (lmer(behavASSORT ~ studyyear + yday.adj + log(nbird) + meanT_FL + meanT_TH + assort_status + hours.per + (1|Lek), data=subset(net.prop, Tplus==0), REML=F))
mod2 <- (lmer(behavASSORT ~ studyyear + yday.adj + log(nbird) + meanT_TH + assort_status + hours.per + (1|Lek), data=subset(net.prop, Tplus==0), REML=F))
mod3 <- (lmer(behavASSORT ~ studyyear + yday.adj + log(nbird) + meanT_FL + assort_status + hours.per + (1|Lek), data=subset(net.prop, Tplus==0), REML=F))
mod4 <- (lmer(behavASSORT ~ studyyear + yday.adj + log(nbird) + assort_status + hours.per + (1|Lek), data=subset(net.prop, Tplus==0), REML=F))
AIC(mod1, mod2, mod3, mod4)[with(AIC(mod1, mod2, mod3, mod4), order(AIC)),]
summary(update(mod1, REML=T)) # n = 80 obs. of 11 leks (80 where Tplus==0, no NAs)

# Plot the best-fit models, partial residuals:

range(Tphen$meanT) # -2.22 to 1.58 Color ramp for testosterone
color.ramp <- data.frame(blup=seq(-2.22, 1.58, by=0.01), color=NA)
color.ramp$color <- colorRampPalette(c('black','blue','red'))(381)
plot(1:381, pch=16, cex=3, col=color.ramp$color)
color.ramp <- rbind(color.ramp, data.frame(blup=NA, color='white'))

# Best-fit models:
mod5A <- (lmer(specialization ~ studyyear + yday.adj + log(nbird) + meanT_TH + hours.per + (1|Lek), data=subset(net.prop, Tplus==0 & !is.na(specialization)), REML=T)); summary(mod5A)

mod5B <- (lmer(stability2 ~ studyyear + yday.adj + log(nbird) + meanT_TH + hours.per + (1|Lek), data=subset(net.prop, Tplus==0 & !is.na(stability2)), REML=T)); summary(mod5B)

mod1C <- (lmer(behavASSORT ~ studyyear + yday.adj + log(nbird) + meanT_FL + meanT_TH + assort_status + hours.per + (1|Lek), data=subset(net.prop, Tplus==0 & !is.na(behavASSORT)), REML=T)); summary(mod1C)

# Partial resid. plots:
A <- visreg(mod5A, 'meanT_TH', plot=F)
B <- visreg(mod5B, 'meanT_TH', plot=F)
C <- visreg(mod1C, 'meanT_TH', plot=F)
(lookup <- data.frame(Lek=sort(unique(net.prop$Lek), decreasing=T), sym=c(1,2,6,5,0,16,17,18,15,3,4)[c(1,7,10,2,6,11,3,8,4,9,5)], col=as.character(colorRampPalette(c('purple','orange'))(11)), stringsAsFactors=F))

dev.new(width=4, height=5) # Scatterplots for figure:
par(mfcol=c(3,2), mar=c(4,4,0.2,0.2), las=1, bty='l', mgp=c(2,0.45,0), tck=-0.02)

plot(visregRes ~ meanT_TH, B[[2]], type='n', pch=16, xlim=c(-0.23,1.35), ylim=c(-0.06,1.1), xlab='Collective avg. T', ylab='Social specialization (res)')
points(visregFit ~ meanT_TH, B[[1]], type='l', lwd=0.75)
points(visregRes ~ meanT_TH, B[[2]], cex=0.65, pch=lookup$sym[match(net.prop$Lek[match(B[[2]]$meanT_TH, net.prop$meanT_TH)], lookup$Lek)], col=color.ramp$color[match(round(B[[2]]$meanT_TH,2), round(color.ramp$blup,2))])

plot(visregRes ~ meanT_TH, A[[2]], type='n', pch=16, xlim=c(-0.23,1.35), ylim=c(-0.06,1.1), xlab='Collective avg. T', ylab='Network stability (res)')
points(visregFit ~ meanT_TH, A[[1]], type='l', lwd=0.75)
points(visregRes ~ meanT_TH, A[[2]], cex=0.65, pch=lookup$sym[match(net.prop$Lek[match(A[[2]]$meanT_TH, net.prop$meanT_TH)], lookup$Lek)], col=color.ramp$color[match(round(A[[2]]$meanT_TH,2), round(color.ramp$blup,2))])

plot(visregRes ~ meanT_TH, C[[2]], type='n', pch=16, xlim=c(-0.23,1.35), ylim=c(-0.5,0.7), xlab='Collective avg. T', ylab='Behavioral assortment (res)')
points(visregFit ~ meanT_TH, C[[1]], type='l', lwd=0.75)
points(visregRes ~ meanT_TH, C[[2]], cex=0.65, pch=lookup$sym[match(net.prop$Lek[match(C[[2]]$meanT_TH, net.prop$meanT_TH)], lookup$Lek)], col=color.ramp$color[match(round(C[[2]]$meanT_TH,2), round(color.ramp$blup,2))])

plot(0:12~c(0:12), type='n', bty='n', xlab='', ylab='', xaxt='n', yaxt='n')
points(1:11 ~ rep(1,11), pch=lookup$sym, col=1, cex=0.65)
text(y=1:11, x=rep(1,11), lookup$Lek, pos=4, cex=0.65)
text(y=12, x=1, 'Network', pos=4, cex=0.65)

# Plot the other significant results, unrelated to main hypothesis:
dev.new(width=4, height=5) 
par(mfrow=c(3,2), mar=c(4,4,0.2,0.2), las=1, bty='l', mgp=c(2,0.45,0), tck=-0.02)
plot(behavASSORT ~ (nbird), net.prop, bty='l', las=1, pch=16, ylim=c(-1,1), xlim=c(3,43))
plot(behavASSORT ~ nbird, summarize(group_by(net.prop, Lek), behavASSORT=mean(behavASSORT), nbird=mean((nbird))), bty='l', las=1, pch=16, ylim=c(-1,1), xlim=c(3,43))
plot(behavASSORT ~ hours.per, net.prop, bty='l', las=1, pch=16, xlim=c(40,100), ylim=c(-1,1))
plot(behavASSORT ~ hours.per, summarize(group_by(net.prop, Lek), behavASSORT=mean(behavASSORT), hours.per=mean(hours.per)), bty='l', las=1, pch=16, xlim=c(40,100), ylim=c(-1,1))


# Get repeatability of lek properties: 
mylekrep <- function(mod){
	data.frame(VarCorr(mod))[,'vcov'][1]/sum(data.frame(VarCorr(mod))[,'vcov'])
}

mod1 <- lmer(meanT_FL ~ studyyear + yday.adj + (1|Lek), data=net.prop)
mylekrep(mod1)
getCIs1 <- bootMer(mod1, mylekrep, nsim=5000)$t; alarm() # 0.30 [0.04, 0.56]
quantile(getCIs1, c(0.025,0.975))

mod2 <- lmer(meanT_TH ~ studyyear + yday.adj + (1|Lek), data=net.prop)
mylekrep(mod2)
getCIs2 <- bootMer(mod2, mylekrep, nsim=5000)$t; alarm() # 0.61 [0.28, 0.79]
quantile(getCIs2, c(0.025,0.975))

mod3 <- lmer(specialization ~ studyyear + yday.adj + (1|Lek), data=net.prop)
mylekrep(mod3)
getCIs3 <- bootMer(mod3, mylekrep, nsim=5000)$t; alarm() # 0.21 [0, 0.47]
quantile(getCIs3, c(0.025,0.975))

mod4 <- lmer(stability2 ~ studyyear + yday.adj + (1|Lek), data=net.prop) 
mylekrep(mod4)
getCIs4 <- bootMer(mod4, mylekrep, nsim=5000)$t; alarm() # 0 [0, 0.22]
quantile(getCIs4, c(0.025,0.975))

mod5 <- lmer(behavASSORT ~ studyyear + yday.adj + (1|Lek), data=net.prop)
mylekrep(mod5)
getCIs5 <- bootMer(mod5, mylekrep, nsim=5000)$t; alarm() # 0.636 [0.08, 0.60]
quantile(getCIs5, c(0.025,0.975))

(repeat.est <- data.frame(R=c(mylekrep(mod3), mylekrep(mod4), mylekrep(mod5), mylekrep(mod1), mylekrep(mod2)), prop=c('spec','stab','ass','collT_FL','collT_TH'), lower=sapply(list(getCIs3, getCIs4, getCIs5, getCIs1, getCIs2), 'quantile', 0.025), upper=sapply(list(getCIs3, getCIs4, getCIs5, getCIs1, getCIs2), 'quantile', 0.975)))
(repeat.est <- structure(list(R = c(0.213004602599855, 0, 0.360052956956411, 
0.302777472547338, 0.605174542496364), prop = structure(c(4L, 
5L, 1L, 2L, 3L), .Label = c("ass", "collT_FL", "collT_TH", "spec", 
"stab"), class = "factor"), lower = c(0, 0, 0.0752727479932079, 
0.0369352762935616, 0.278390999165062), upper = c(0.467415034556686, 
0.219688352709337, 0.602145866514072, 0.555640345503215, 0.79444402783443
)), class = "data.frame", row.names = c(NA, -5L)))


dev.new(width=5.5, height=5.5)
par(mfcol=c(3,3), mar=c(4,4,2,0.2), las=1, bty='l', mgp=c(2,0.45,0), tck=-0.02)
h1 <- hist(net.prop$specialization, main='', xlab='Social specialization', breaks=10, col=rgb(0,0,0,0), border=rgb(0,0,0,0.5), ylim=c(0,35))
d1 <- density(net.prop$specialization, na.rm=T)
d1$y <- d1$y/max(d1$y) * max(h1$counts)
polygon(x=c(d1$x, rev(d1$x)), y=c(d1$y, rep(0, length(d1$y))), col=rgb(0,0,0,0.2))

h1 <- hist(net.prop$stability2, main='', xlab='Network stability', breaks=10, col=rgb(0,0,0,0), border=rgb(0,0,0,0.5), ylim=c(0,35))
d1 <- density(net.prop$stability2, na.rm=T)
d1$y <- d1$y/max(d1$y) * max(h1$counts)
polygon(x=c(d1$x, rev(d1$x)), y=c(d1$y, rep(0, length(d1$y))), col=rgb(0,0,0,0.2))

# plot.new()
plot(repeat.est$R ~ c(1:5), pch=16, ylab='Repeatability', xlab='', xaxt='n', ylim=c(0,1))
segments(x0=1:5, y0=repeat.est$lower, y1=repeat.est$upper)
axis(1, at=1:5, labels=repeat.est$prop, las=2)

h1 <- hist(net.prop$behavASSORT, xlim=c(-1,1), main='', xlab='Behavioral assortment', breaks=10, col=rgb(0,0,0,0), border=rgb(0,0,0,0.5), ylim=c(0,35))
d1 <- density(net.prop$behavASSORT, na.rm=T)
d1$y <- d1$y/max(d1$y) * max(h1$counts)
polygon(x=c(d1$x, rev(d1$x)), y=c(d1$y, rep(0, length(d1$y))), col=rgb(0,0,0,0.2))

h1 <- hist(net.prop$assort_status, xlim=c(-1,1), main='', xlab='Status assortment', breaks=10, col=rgb(0,0,0,0), border=rgb(0,0,0,0.5), ylim=c(0,35))
d1 <- density(net.prop$assort_status, na.rm=T)
d1$y <- d1$y/max(d1$y) * max(h1$counts)
polygon(x=c(d1$x, rev(d1$x)), y=c(d1$y, rep(0, length(d1$y))), col=rgb(0,0,0,0.2))

plot(behavASSORT ~ assort_status, net.prop, pch=16, col=rgb(0,0,0,0.5), xlab='Status assortment', ylab='Behavioral assortment', xlim=c(-1,1), ylim=c(-1,1)); abline(a=0,b=1,lty=3)

h1 <- hist(net.prop$meanT_FL, main='', xlab='Collective testosterone (FL)', breaks=10, col=rgb(0,0,0,0), border=rgb(0,0,0,0.5), xlim=c(-1.7,1.4), ylim=c(0,35))
d1 <- density(net.prop$meanT_FL, na.rm=T)
d1$y <- d1$y/max(d1$y) * max(h1$counts)
polygon(x=c(d1$x, rev(d1$x)), y=c(d1$y, rep(0, length(d1$y))), col=rgb(0,0,0,0.2))

h1 <- hist(net.prop$meanT_TH, main='', xlab='Collective testosterone (TH)', breaks=10, col=rgb(0,0,0,0), border=rgb(0,0,0,0.5), xlim=c(-1.7,1.4), ylim=c(0,35))
d1 <- density(net.prop$meanT_TH, na.rm=T)
d1$y <- d1$y/max(d1$y) * max(h1$counts)
polygon(x=c(d1$x, rev(d1$x)), y=c(d1$y, rep(0, length(d1$y))), col=rgb(0,0,0,0.2))

plot(meanT_FL ~ meanT_TH, net.prop, pch=16, col=rgb(0,0,0,0.5), xlab='Collective testosterone (TH)', ylab='Collective testosterone (FL)', xlim=c(-1.7,1.4), ylim=c(-1.7,1.4)); abline(a=0,b=1,lty=3)


# Additional descriptive statistics of lek size and sampling regime:

nsum <- summarize(group_by(subset(net.prop, Tplus==0), Lek), nbird=mean(nbird), yday.adj=mean(yday.adj), hours.per=mean(hours.per)); nsum <- nsum[with(nsum, order(nbird)),]

layout(matrix(data=c(1,1,2,3,3,4,5,5,6), byrow=T,nrow=3, ncol=3))
par(las=1, mgp=c(2,0.35,0), mar=c(2.5,2.5,0.2,0.2), bty='l', tck=-0.02)
plot(jitter(log(nbird),5) ~ jitter(as.numeric(factor(Lek, levels=nsum$Lek))), data=subset(net.prop, Tplus==0), pch=16, cex=0.65, col=rgb(0,0,0,0.5), xlab='', ylab='', xaxt='n', yaxt='n', ylim=log(c(2,50)))
axis(2, at=log(c(seq(2,10,by=2),20,30,40)), labels=c(seq(2,10,by=2),20,30,40), cex.axis=0.5)
axis(1, at=1:11, labels=nsum$Lek, cex.axis=0.5)
segments(x0=(1:11)-0.3, x1=(1:11)+0.3, y0=log(nsum$nbird))
hist(log(subset(net.prop, Tplus==0)$nbird), breaks=19, main='', xlab='', ylab='', xlim=log(c(2,50)), xaxt='n', col='light grey', ylim=c(0,50))
axis(1, at=log(c(seq(2,10,by=2),20,30,40)), labels=c(seq(2,10,by=2),20,30,40), cex.axis=0.5)
plot(yday.adj ~ jitter(as.numeric(factor(Lek, levels=nsum$Lek))), data=subset(net.prop, Tplus==0), pch=16, cex=0.65, col=rgb(0,0,0,0.5), xlab='', ylab='', xaxt='n', yaxt='n', ylim=c(-20,70))
axis(1, at=1:11, labels=nsum$Lek, cex.axis=0.5)
axis(2, at=c(-20,0,20,40,60), cex.axis=0.5)
segments(x0=(1:11)-0.3, x1=(1:11)+0.3, y0=(nsum$yday.adj))
hist(subset(net.prop, Tplus==0)$yday.adj, breaks=19, main='', xlab='', ylab='', xlim=c(-20,70), xaxt='n', col='light grey', ylim=c(0,50))
axis(1, at=c(-20,0,20,40,60), cex.axis=0.5)
plot(jitter(hours.per,50) ~ jitter(as.numeric(factor(Lek, levels=nsum$Lek))), data=subset(net.prop, Tplus==0), pch=16, cex=0.65, col=rgb(0,0,0,0.5), xlab='', ylab='', xaxt='n', yaxt='n', ylim=c(40,103))
axis(1, at=1:11, labels=nsum$Lek, cex.axis=0.5)
axis(2, at=c(40,60,80,100), cex.axis=0.5)
segments(x0=(1:11)-0.3, x1=(1:11)+0.3, y0=(nsum$hours.per))
hist(subset(net.prop, Tplus==0)$hours.per, breaks=20, main='', xlab='', ylab='', xlim=c(40,103), xaxt='n', col='light grey', ylim=c(0,50))
axis(1, at=c(40,60,80,100), cex.axis=0.5)

# Data for Table 1:

(desc.stat <- data.frame(summarize(group_by(subset(net.prop, Tplus==0), studyyear), mean(nbird), sd(nbird), mean(specialization, na.rm=T), sd(specialization, na.rm=T), mean(stability2, na.rm=T), sd(stability2, na.rm=T), mean(behavASSORT), sd(behavASSORT), mean(meanT_TH), sd(meanT_TH), mean(meanT_FL), sd(meanT_FL)))) 

# How often do the different status classes interact?

dev.new(width=6, height=2)
par(mfrow=c(1,3), las=1, mgp=c(2,0.35,0), mar=c(4,4,0.2,0.2), bty='l', tck=-0.02)
plot(hetero.int ~ log(nbird), subset(net.prop, Tplus==0), pch=16, ylim=c(0,1), xaxt='n', yaxt='n')
abline(h=mean(subset(net.prop, Tplus==0)$hetero.int), lty=3)
axis(1, at=log(c(3:10,20,30,40)), labels=c(3:10,20,30,40), cex.axis=0.5)
axis(2, at=c(0,0.50,1.00), labels=c(0,50,100))
plot(terr.terr.int ~ log(nbird), subset(net.prop, Tplus==0), pch=16, ylim=c(0,1), xaxt='n', yaxt='n')
abline(h=mean(subset(net.prop, Tplus==0)$terr.terr.int), lty=3)
axis(1, at=log(c(3:10,20,30,40)), labels=c(3:10,20,30,40), cex.axis=0.5)
axis(2, at=c(0,0.50,1.00), labels=c(0,50,100))
plot(floa.floa.int ~ log(nbird), subset(net.prop, Tplus==0), pch=16, ylim=c(0,1), xaxt='n', yaxt='n')
abline(h=mean(subset(net.prop, Tplus==0)$floa.floa.int), lty=3)
axis(1, at=log(c(3:10,20,30,40)), labels=c(3:10,20,30,40), cex.axis=0.5)
axis(2, at=c(0,0.50,1.00), labels=c(0,50,100))



# Plot example networks:

dev.new(width=5.5, height=5.5)
par(mfcol=c(2,2), mar=c(0,0,0,0)) # Node and edge sizes scaled to max. within each network for visibility.

i <- 18 # Low specialization
yr <- net.prop$studyyear[i]
lk <- net.prop$Lek[i]
dl <- net.prop$DL[i]	
g1.0 <- subset(ally, studyyear==yr & Lek==lk & DL==dl)[,c('Color1','Color2','sitefix','date')]
g1a <- unique(g1.0[,c('Color1','Color2')]) # duplicate interactions
g1a <- subset(g1a, Color1<Color2) # removes duplicates
temp <- summarize(group_by(g1.0, Color1, Color2), n=n())
g1a$raw.weight <- temp$n[match(paste(g1a$Color1, g1a$Color2),  paste(temp$Color1, temp$Color2))]
ggg <- graph.data.frame(data.frame(Color1=g1a$Color1, Color2=g1a$Color2, weight=g1a$raw.weight), directed=F) # Build the network
temp <- subset(phen, (!timesincemanip %in% c(1:10)) & studyyear==yr & ID1 %in% names(V(ggg)) & date %in% as.Date(unique(g1.0$date)))[,c('ID1','date','pingsL','num.intL','num.partL','Status')] 
temp <- summarize(group_by(temp, ID1, Status), effort=mean(pingsL), strength=mean(num.intL), degree=mean(num.partL))
temp <- temp[match(names(V(ggg)), temp$ID1),] # sort
temp$ID1 <- names(V(ggg))
temp$Status[is.na(temp$Status)] <- unique(subset(phen, studyyear==yr)[,c('ID1','Status')])$Status[match(temp$ID1[is.na(temp$Status)], 	unique(subset(phen, studyyear==yr)[,c('ID1','Status')])$ID1)]
temp$scol <- ifelse(temp$Status=='floa', 'red', 'black')
plot(ggg, layout=layout_with_lgl, vertex.label=NA, vertex.color=temp$scol,
vertex.size=20*log(igraph::strength(ggg)+5)/max(log(igraph::strength(ggg)+5)),
edge.width=5*(log(edge_attr(ggg)$weight+1))/max((log(edge_attr(ggg)$weight+1))))
text(0,-1, round(net.prop$specialization[i], 2))

ggg2 <- as_adj(ggg, sparse=F, attr='weight') # Adjacency matrix
cnames <- names(V(ggg))[names(V(ggg)) %in% unique(g1.0$sitefix)]
rnames <- names(V(ggg))[!names(V(ggg)) %in% unique(g1.0$sitefix)]
bip <- as.matrix(ggg2[rnames, cnames], nrow=length(rnames), ncol=length(cnames)) # Trimmed
plotweb(log(bip+1))


i <- 71 # High specialization
yr <- net.prop$studyyear[i]
lk <- net.prop$Lek[i]
dl <- net.prop$DL[i]	
g1.0 <- subset(ally, studyyear==yr & Lek==lk & DL==dl)[,c('Color1','Color2','sitefix','date')]
g1a <- unique(g1.0[,c('Color1','Color2')]) # duplicate interactions
g1a <- subset(g1a, Color1<Color2) # removes duplicates
temp <- summarize(group_by(g1.0, Color1, Color2), n=n())
g1a$raw.weight <- temp$n[match(paste(g1a$Color1, g1a$Color2),  paste(temp$Color1, temp$Color2))]
ggg <- graph.data.frame(data.frame(Color1=g1a$Color1, Color2=g1a$Color2, weight=g1a$raw.weight), directed=F) # Build the network
temp <- subset(phen, (!timesincemanip %in% c(1:10)) & studyyear==yr & ID1 %in% names(V(ggg)) & date %in% as.Date(unique(g1.0$date)))[,c('ID1','date','pingsL','num.intL','num.partL','Status')] 
temp <- summarize(group_by(temp, ID1, Status), effort=mean(pingsL), strength=mean(num.intL), degree=mean(num.partL))
temp <- temp[match(names(V(ggg)), temp$ID1),] # sort
temp$ID1 <- names(V(ggg))
temp$Status[is.na(temp$Status)] <- unique(subset(phen, studyyear==yr)[,c('ID1','Status')])$Status[match(temp$ID1[is.na(temp$Status)], 	unique(subset(phen, studyyear==yr)[,c('ID1','Status')])$ID1)]
temp$scol <- ifelse(temp$Status=='floa', 'red', 'black')
plot(ggg, layout=layout_with_lgl, vertex.label=NA, vertex.color=temp$scol,
vertex.size=20*log(igraph::strength(ggg)+5)/max(log(igraph::strength(ggg)+5)),
edge.width=5*(log(edge_attr(ggg)$weight+1))/max((log(edge_attr(ggg)$weight+1))))
text(0,-1, round(net.prop$specialization[i], 2))

ggg2 <- as_adj(ggg, sparse=F, attr='weight') # Adjacency matrix
cnames <- names(V(ggg))[names(V(ggg)) %in% unique(g1.0$sitefix)]
rnames <- names(V(ggg))[!names(V(ggg)) %in% unique(g1.0$sitefix)]
bip <- as.matrix(ggg2[rnames, cnames], nrow=length(rnames), ncol=length(cnames)) # Trimmed
plotweb(log(bip+1))

dev.new(width=5.5, height=5.5)
par(mfrow=c(2,2), mar=c(0,0,0,0))

i <- 50 # Neg. assortment
yr <- net.prop$studyyear[i]
lk <- net.prop$Lek[i]
dl <- net.prop$DL[i]	
g1.0 <- subset(ally, studyyear==yr & Lek==lk & DL==dl)[,c('Color1','Color2','sitefix','date')]
g1a <- unique(g1.0[,c('Color1','Color2')]) # duplicate interactions
g1a <- subset(g1a, Color1<Color2) # removes duplicates
temp <- summarize(group_by(g1.0, Color1, Color2), n=n())
g1a$raw.weight <- temp$n[match(paste(g1a$Color1, g1a$Color2),  paste(temp$Color1, temp$Color2))]
ggg <- graph.data.frame(data.frame(Color1=g1a$Color1, Color2=g1a$Color2, weight=g1a$raw.weight), directed=F) # Build the network
temp <- subset(phen, (!timesincemanip %in% c(1:10)) & studyyear==yr & ID1 %in% names(V(ggg)) & date %in% as.Date(unique(g1.0$date)))[,c('ID1','date','pingsL','num.intL','num.partL','Status')] 
temp <- summarize(group_by(temp, ID1, Status), effort=mean(pingsL), strength=mean(num.intL), degree=mean(num.partL))
temp <- temp[match(names(V(ggg)), temp$ID1),] # sort
temp$ID1 <- names(V(ggg))
temp$Status[is.na(temp$Status)] <- unique(subset(phen, studyyear==yr)[,c('ID1','Status')])$Status[match(temp$ID1[is.na(temp$Status)], 	unique(subset(phen, studyyear==yr)[,c('ID1','Status')])$ID1)]
temp$scol <- ifelse(temp$Status=='floa', 'red', 'black')
mycols <- colorRampPalette(c(rgb(1,1,1,1), rgb(0.65,0.65,0.65,1), rgb(0,0,0,1)))(length(seq(0,3.5,by=0.01)))
# colorRampPalette(c('orange','red','blue'))(length(seq(0,3.5,by=0.01)))
temp$stcol <- mycols[round(temp$strength,2)*100]
plot(ggg, layout=layout_with_lgl, vertex.label=NA, vertex.color=temp$stcol,
vertex.size=20*log(igraph::strength(ggg)+5)/max(log(igraph::strength(ggg)+5)),
edge.width=5*(log(edge_attr(ggg)$weight+1))/max((log(edge_attr(ggg)$weight+1))))
text(0,-1, round(net.prop$behavASSORT[i], 2))

i <- 81 # Pos. assortment
yr <- net.prop$studyyear[i]
lk <- net.prop$Lek[i]
dl <- net.prop$DL[i]	
g1.0 <- subset(ally, studyyear==yr & Lek==lk & DL==dl)[,c('Color1','Color2','sitefix','date')]
g1a <- unique(g1.0[,c('Color1','Color2')]) # duplicate interactions
g1a <- subset(g1a, Color1<Color2) # removes duplicates
temp <- summarize(group_by(g1.0, Color1, Color2), n=n())
g1a$raw.weight <- temp$n[match(paste(g1a$Color1, g1a$Color2),  paste(temp$Color1, temp$Color2))]
ggg <- graph.data.frame(data.frame(Color1=g1a$Color1, Color2=g1a$Color2, weight=g1a$raw.weight), directed=F) # Build the network
temp <- subset(phen, (!timesincemanip %in% c(1:10)) & studyyear==yr & ID1 %in% names(V(ggg)) & date %in% as.Date(unique(g1.0$date)))[,c('ID1','date','pingsL','num.intL','num.partL','Status')] 
temp <- summarize(group_by(temp, ID1, Status), effort=mean(pingsL), strength=mean(num.intL), degree=mean(num.partL))
temp <- temp[match(names(V(ggg)), temp$ID1),] # sort
temp$ID1 <- names(V(ggg))
temp$Status[is.na(temp$Status)] <- unique(subset(phen, studyyear==yr)[,c('ID1','Status')])$Status[match(temp$ID1[is.na(temp$Status)], 	unique(subset(phen, studyyear==yr)[,c('ID1','Status')])$ID1)]
temp$scol <- ifelse(temp$Status=='floa', 'red', 'black')
mycols <- colorRampPalette(c(rgb(1,1,1,1), rgb(0.65,0.65,0.65,1), rgb(0,0,0,1)))(length(seq(0,3.5,by=0.01)))
# colorRampPalette(c('orange','red','blue'))(length(seq(0,3.5,by=0.01)))
temp$stcol <- mycols[round(temp$strength,2)*100]
plot(ggg, layout=layout_with_lgl, vertex.label=NA, vertex.color=temp$stcol,
vertex.size=20*log(igraph::strength(ggg)+5)/max(log(igraph::strength(ggg)+5)),
edge.width=5*(log(edge_attr(ggg)$weight+1))/max((log(edge_attr(ggg)$weight+1))))
text(0,-1, round(net.prop$behavASSORT[i], 2))


# Plot the testosterone data:

# Color ramps, opaque for territory-holders:
range(Tphen$meanT) # -2.22 to 1.58
color.ramp <- data.frame(blup=seq(-2.22, 1.58, by=0.01), color=NA)
color.ramp$color <- colorRampPalette(c('black','blue','red'))(381)
plot(1:381, pch=16, cex=3, col=color.ramp$color)
color.ramp <- rbind(color.ramp, data.frame(blup=NA, color='white'))

# Semi-transparent ramp for floaters:
color.rampF <- data.frame(blup=seq(-2.22, 1.58, by=0.01), color=NA)
color.rampF$color <- colorRampPalette(c(rgb(0.75,0.75,0.75), rgb(0.75,0.75,1), rgb(1,0.75,0.75)))(381)
plot(1:381, pch=16, cex=3, col=color.rampF$color)
color.rampF <- rbind(color.rampF, data.frame(blup=NA, color='white'))

myfun <- colorRampPalette(c('black','blue','red'))
myfunF <- colorRampPalette(c(rgb(0.5,0.5,0.5), rgb(0.5,0.5,1), rgb(1,0.5,0.5)))

Tplotdat <- subset(Tphen, ID %in% names(table(Tphen$ID)[table(Tphen$ID)>2]))
bluprank <- unique(Tplotdat[,c('ID','meanT')])[with(unique(Tplotdat[,c('ID','meanT')]), order(meanT)),]
blupstat <- summarize(group_by(Tplotdat, ID), St=names(sort(table(Status), decreasing=T))[1])
bluprank$Status <- blupstat$St[match(bluprank$ID, blupstat$ID)]
bluprank$col <- color.ramp$color[match(round(bluprank$meanT,2), round(color.ramp$blup,2))]
bluprank$col <- ifelse(bluprank$Status=='terr', bluprank$col, adjustcolor(bluprank$col, alpha.f=0.25))
Tplotdat$IDF <- factor(Tplotdat$ID, levels=bluprank$ID)

dev.new(width=4, height=1) # Testoserone caterpillar plot:
par(bty='l', las=1, tck=-0.05, mar=c(0.2,4,0.2,0.2), mgp=c(1,0.5,0))
boxplot(logT ~ (IDF), Tplotdat, xlab='', ylab='Log T (ng/ml)', xaxt='n', outline=F, range=0, col=bluprank$col, cex.lab=0.75, cex.axis=0.75, border=1, lwd=0.1, lty=1)


adjustcolor(bluprank$col, alpha.f=0.5)

# row 45.
# row 23

dev.new(width=6, height=6) # Plot example networks with individual and collective T illustrated:
layout(matrix(c(1,1,2,3,3,4, 1,1,2,3,3,4, 5,5,6,7,7,8, 5,5,6,7,7,8, 9,9,10,11,11,12, 9,9,10,11,11,12 ), nrow=6, ncol=6, byrow=T))

par(mar=rep(0.1,4))
i <- 52 # 23
yr <- net.prop$studyyear[i]
lk <- net.prop$Lek[i]
dl <- net.prop$DL[i]
temp <- subset(ally, studyyear==yr & Lek==lk & DL==dl)
g1a <- unique(temp[,c('Color1','Color2')])
g1a <- subset(g1a, Color1<Color2) 
temp <- summarize(group_by(temp, Color1, Color2), n=n())
g1a$raw.weight <- temp$n[match(paste(g1a$Color1, g1a$Color2),  paste(temp$Color1, temp$Color2))]; g1b <- g1a
g1w <- graph.data.frame(data.frame(Color1=g1b$Color1, Color2=g1b$Color2, weight=g1b$raw.weight), directed=F)
Tvals <- round(subset(Tphen, studyyear==yr)[match(names(V(g1w)), subset(Tphen, studyyear==yr)$ID),]$meanT,2)
Tvals <- ifelse(subset(Tphen, studyyear==yr)[match(names(V(g1w)), subset(Tphen, studyyear==yr)$ID),]$Status=='floa', color.rampF[match(Tvals, round(color.rampF$blup,2)), 'color'], color.ramp[match(Tvals, round(color.ramp$blup,2)), 'color'])
plot(g1w, layout= layout_with_lgl, vertex.size=5*log(igraph::strength(g1w)+1), edge.width=2*log(edge_attr(g1w)$weight+1), vertex.label=NA, vertex.color=Tvals, vertex.frame.color=ifelse(subset(Tphen, studyyear==yr)[match(names(V(g1w)), subset(Tphen, studyyear==yr)$ID),]$Status=='floa', Tvals, 'black'))
text(0,1,net.prop$Lek[i])
text(0,-1,round(net.prop$meanT_TH[i],2))
text(0,-1.1,round(net.prop$meanT_FL[i],2))

# Legend
par(mar=c(1,1,1,4))
plot(0, type='n', xlim=c(-1,1), ylim=c(-2.2,1.6), bty='n', xaxt='n', yaxt='n') # 
plotfunctions::gradientLegend(valRange=c(-2.2,1.6), pos=0.5, inside=T, depth=0.3, length=1, n.seg=0, color=myfunF(381), border.col='grey')
points(x=0.2, y=net.prop$meanT_FL[i], pch=-9658, cex=1)

plotfunctions::gradientLegend(valRange=c(-2.2,1.6), pos=0.5, inside=F, depth=0.3, length=1, n.seg=0, color=myfun(381), border.col='grey')
segments(x0=rep(1.75,5), x1=rep(2.05,5), y0=c(-2,-1,0,1))
text(x=1.9, y=c(-2,-1,0,1), c(-2,-1,0,1), pos=4, cex=0.75)
points(x=0.9, y=net.prop$meanT_TH[i], pch=-9658, cex=1)

par(mar=rep(0.1,4))
i <- 45
yr <- net.prop$studyyear[i]
yr <- net.prop$studyyear[i]
lk <- net.prop$Lek[i]
dl <- net.prop$DL[i]
temp <- subset(ally, studyyear==yr & Lek==lk & DL==dl)
g1a <- unique(temp[,c('Color1','Color2')])
g1a <- subset(g1a, Color1<Color2) 
temp <- summarize(group_by(temp, Color1, Color2), n=n())
g1a$raw.weight <- temp$n[match(paste(g1a$Color1, g1a$Color2),  paste(temp$Color1, temp$Color2))]; g1b <- g1a
g1w <- graph.data.frame(data.frame(Color1=g1b$Color1, Color2=g1b$Color2, weight=g1b$raw.weight), directed=F)
Tvals <- round(subset(Tphen, studyyear==yr)[match(names(V(g1w)), subset(Tphen, studyyear==yr)$ID),]$meanT,2)
Tvals <- ifelse(subset(Tphen, studyyear==yr)[match(names(V(g1w)), subset(Tphen, studyyear==yr)$ID),]$Status=='floa', color.rampF[match(Tvals, round(color.rampF$blup,2)), 'color'], color.ramp[match(Tvals, round(color.ramp$blup,2)), 'color'])
plot(g1w, layout= layout_with_lgl, vertex.size=5*log(igraph::strength(g1w)+1), edge.width=2*log(edge_attr(g1w)$weight+1), vertex.label=NA, vertex.color=Tvals, vertex.frame.color=ifelse(subset(Tphen, studyyear==yr)[match(names(V(g1w)), subset(Tphen, studyyear==yr)$ID),]$Status=='floa', Tvals, 'black'))
text(0,1,net.prop$Lek[i])
text(0,-1,round(net.prop$meanT_TH[i],2))
text(0,-1.1,round(net.prop$meanT_FL[i],2))

# Legend
par(mar=c(1,1,1,4))
plot(0, type='n', xlim=c(-1,1), ylim=c(-2.2,1.6), bty='n', xaxt='n', yaxt='n') # 
plotfunctions::gradientLegend(valRange=c(-2.2,1.6), pos=0.5, inside=T, depth=0.3, length=1, n.seg=0, color=myfunF(381), border.col='grey')
points(x=0.2, y=net.prop$meanT_FL[i], pch=-9658, cex=1)

plotfunctions::gradientLegend(valRange=c(-2.2,1.6), pos=0.5, inside=F, depth=0.3, length=1, n.seg=0, color=myfun(381), border.col='grey')
segments(x0=rep(1.75,5), x1=rep(2.05,5), y0=c(-2,-1,0,1))
text(x=1.9, y=c(-2,-1,0,1), c(-2,-1,0,1), pos=4, cex=0.75)
points(x=0.9, y=net.prop$meanT_TH[i], pch=-9658, cex=1)

par(mar=rep(0.1,4))
i <- 7 # 40
yr <- net.prop$studyyear[i]
lk <- net.prop$Lek[i]
dl <- net.prop$DL[i]
temp <- subset(ally, studyyear==yr & Lek==lk & DL==dl)
g1a <- unique(temp[,c('Color1','Color2')])
g1a <- subset(g1a, Color1<Color2) 
temp <- summarize(group_by(temp, Color1, Color2), n=n())
g1a$raw.weight <- temp$n[match(paste(g1a$Color1, g1a$Color2),  paste(temp$Color1, temp$Color2))]; g1b <- g1a
g1w <- graph.data.frame(data.frame(Color1=g1b$Color1, Color2=g1b$Color2, weight=g1b$raw.weight), directed=F)
Tvals <- round(subset(Tphen, studyyear==yr)[match(names(V(g1w)), subset(Tphen, studyyear==yr)$ID),]$meanT,2)
Tvals <- ifelse(subset(Tphen, studyyear==yr)[match(names(V(g1w)), subset(Tphen, studyyear==yr)$ID),]$Status=='floa', color.rampF[match(Tvals, round(color.rampF$blup,2)), 'color'], color.ramp[match(Tvals, round(color.ramp$blup,2)), 'color'])
plot(g1w, layout= layout_with_lgl, vertex.size=5*log(igraph::strength(g1w)+1), edge.width=2*log(edge_attr(g1w)$weight+1), vertex.label=NA, vertex.color=Tvals, vertex.frame.color=ifelse(subset(Tphen, studyyear==yr)[match(names(V(g1w)), subset(Tphen, studyyear==yr)$ID),]$Status=='floa', Tvals, 'black'))
text(0,1,net.prop$Lek[i])
text(0,-1,round(net.prop$meanT_TH[i],2))
text(0,-1.1,round(net.prop$meanT_FL[i],2))

# Legend
par(mar=c(1,1,1,4))
plot(0, type='n', xlim=c(-1,1), ylim=c(-2.2,1.6), bty='n', xaxt='n', yaxt='n') # 
plotfunctions::gradientLegend(valRange=c(-2.2,1.6), pos=0.5, inside=T, depth=0.3, length=1, n.seg=0, color=myfunF(381), border.col='grey')
points(x=0.2, y=net.prop$meanT_FL[i], pch=-9658, cex=1)

plotfunctions::gradientLegend(valRange=c(-2.2,1.6), pos=0.5, inside=F, depth=0.3, length=1, n.seg=0, color=myfun(381), border.col='grey')
segments(x0=rep(1.75,5), x1=rep(2.05,5), y0=c(-2,-1,0,1))
text(x=1.9, y=c(-2,-1,0,1), c(-2,-1,0,1), pos=4, cex=0.75)
points(x=0.9, y=net.prop$meanT_TH[i], pch=-9658, cex=1)

par(mar=rep(0.1,4))
i <- 6
yr <- net.prop$studyyear[i]
lk <- net.prop$Lek[i]
dl <- net.prop$DL[i]
temp <- subset(ally, studyyear==yr & Lek==lk & DL==dl)
g1a <- unique(temp[,c('Color1','Color2')])
g1a <- subset(g1a, Color1<Color2) 
temp <- summarize(group_by(temp, Color1, Color2), n=n())
g1a$raw.weight <- temp$n[match(paste(g1a$Color1, g1a$Color2),  paste(temp$Color1, temp$Color2))]; g1b <- g1a
g1w <- graph.data.frame(data.frame(Color1=g1b$Color1, Color2=g1b$Color2, weight=g1b$raw.weight), directed=F)
Tvals <- round(subset(Tphen, studyyear==yr)[match(names(V(g1w)), subset(Tphen, studyyear==yr)$ID),]$meanT,2)
Tvals <- ifelse(subset(Tphen, studyyear==yr)[match(names(V(g1w)), subset(Tphen, studyyear==yr)$ID),]$Status=='floa', color.rampF[match(Tvals, round(color.rampF$blup,2)), 'color'], color.ramp[match(Tvals, round(color.ramp$blup,2)), 'color'])
plot(g1w, layout= layout_with_lgl, vertex.size=5*log(igraph::strength(g1w)+1), edge.width=2*log(edge_attr(g1w)$weight+1), vertex.label=NA, vertex.color=Tvals, vertex.frame.color=ifelse(subset(Tphen, studyyear==yr)[match(names(V(g1w)), subset(Tphen, studyyear==yr)$ID),]$Status=='floa', Tvals, 'black'))
text(0,1,net.prop$Lek[i])
text(0,-1,round(net.prop$meanT_TH[i],2))
text(0,-1.1,round(net.prop$meanT_FL[i],2))

# Legend
par(mar=c(1,1,1,4))
plot(0, type='n', xlim=c(-1,1), ylim=c(-2.2,1.6), bty='n', xaxt='n', yaxt='n') # 
plotfunctions::gradientLegend(valRange=c(-2.2,1.6), pos=0.5, inside=T, depth=0.3, length=1, n.seg=0, color=myfunF(381), border.col='grey')
points(x=0.2, y=net.prop$meanT_FL[i], pch=-9658, cex=1)

plotfunctions::gradientLegend(valRange=c(-2.2,1.6), pos=0.5, inside=F, depth=0.3, length=1, n.seg=0, color=myfun(381), border.col='grey')
segments(x0=rep(1.75,5), x1=rep(2.05,5), y0=c(-2,-1,0,1))
text(x=1.9, y=c(-2,-1,0,1), c(-2,-1,0,1), pos=4, cex=0.75)
points(x=0.9, y=net.prop$meanT_TH[i], pch=-9658, cex=1)

par(mar=rep(0.1,4))
i <- 55
yr <- net.prop$studyyear[i]
lk <- net.prop$Lek[i]
dl <- net.prop$DL[i]
temp <- subset(ally, studyyear==yr & Lek==lk & DL==dl)
g1a <- unique(temp[,c('Color1','Color2')])
g1a <- subset(g1a, Color1<Color2) 
temp <- summarize(group_by(temp, Color1, Color2), n=n())
g1a$raw.weight <- temp$n[match(paste(g1a$Color1, g1a$Color2),  paste(temp$Color1, temp$Color2))]; g1b <- g1a
g1w <- graph.data.frame(data.frame(Color1=g1b$Color1, Color2=g1b$Color2, weight=g1b$raw.weight), directed=F)
Tvals <- round(subset(Tphen, studyyear==yr)[match(names(V(g1w)), subset(Tphen, studyyear==yr)$ID),]$meanT,2)
Tvals <- ifelse(subset(Tphen, studyyear==yr)[match(names(V(g1w)), subset(Tphen, studyyear==yr)$ID),]$Status=='floa', color.rampF[match(Tvals, round(color.rampF$blup,2)), 'color'], color.ramp[match(Tvals, round(color.ramp$blup,2)), 'color'])
plot(g1w, layout= layout_with_lgl, vertex.size=5*log(igraph::strength(g1w)+1), edge.width=2*log(edge_attr(g1w)$weight+1), vertex.label=NA, vertex.color=Tvals, vertex.frame.color=ifelse(subset(Tphen, studyyear==yr)[match(names(V(g1w)), subset(Tphen, studyyear==yr)$ID),]$Status=='floa', Tvals, 'black'))
text(0,1,net.prop$Lek[i])
text(0,-1,round(net.prop$meanT_TH[i],2))
text(0,-1.1,round(net.prop$meanT_FL[i],2))

# Legend
par(mar=c(1,1,1,4))
plot(0, type='n', xlim=c(-1,1), ylim=c(-2.2,1.6), bty='n', xaxt='n', yaxt='n') # 
plotfunctions::gradientLegend(valRange=c(-2.2,1.6), pos=0.5, inside=T, depth=0.3, length=1, n.seg=0, color=myfunF(381), border.col='grey')
points(x=0.2, y=net.prop$meanT_FL[i], pch=-9658, cex=1)

plotfunctions::gradientLegend(valRange=c(-2.2,1.6), pos=0.5, inside=F, depth=0.3, length=1, n.seg=0, color=myfun(381), border.col='grey')
segments(x0=rep(1.75,5), x1=rep(2.05,5), y0=c(-2,-1,0,1))
text(x=1.9, y=c(-2,-1,0,1), c(-2,-1,0,1), pos=4, cex=0.75)
points(x=0.9, y=net.prop$meanT_TH[i], pch=-9658, cex=1)

par(mar=rep(0.1,4))
i <- 73
yr <- net.prop$studyyear[i]
lk <- net.prop$Lek[i]
dl <- net.prop$DL[i]
temp <- subset(ally, studyyear==yr & Lek==lk & DL==dl)
g1a <- unique(temp[,c('Color1','Color2')])
g1a <- subset(g1a, Color1<Color2) 
temp <- summarize(group_by(temp, Color1, Color2), n=n())
g1a$raw.weight <- temp$n[match(paste(g1a$Color1, g1a$Color2),  paste(temp$Color1, temp$Color2))]; g1b <- g1a
g1w <- graph.data.frame(data.frame(Color1=g1b$Color1, Color2=g1b$Color2, weight=g1b$raw.weight), directed=F)
Tvals <- round(subset(Tphen, studyyear==yr)[match(names(V(g1w)), subset(Tphen, studyyear==yr)$ID),]$meanT,2)
Tvals <- ifelse(subset(Tphen, studyyear==yr)[match(names(V(g1w)), subset(Tphen, studyyear==yr)$ID),]$Status=='floa', color.rampF[match(Tvals, round(color.rampF$blup,2)), 'color'], color.ramp[match(Tvals, round(color.ramp$blup,2)), 'color'])
plot(g1w, layout= layout_with_lgl, vertex.size=5*log(igraph::strength(g1w)+1), edge.width=2*log(edge_attr(g1w)$weight+1), vertex.label=NA, vertex.color=Tvals, vertex.frame.color=ifelse(subset(Tphen, studyyear==yr)[match(names(V(g1w)), subset(Tphen, studyyear==yr)$ID),]$Status=='floa', Tvals, 'black'))
text(0,1,net.prop$Lek[i])
text(0,-1,round(net.prop$meanT_TH[i],2))
text(0,-1.1,round(net.prop$meanT_FL[i],2))

# Legend
par(mar=c(1,1,1,4))
plot(0, type='n', xlim=c(-1,1), ylim=c(-2.2,1.6), bty='n', xaxt='n', yaxt='n') # 
plotfunctions::gradientLegend(valRange=c(-2.2,1.6), pos=0.5, inside=T, depth=0.3, length=1, n.seg=0, color=myfunF(381), border.col='grey')
points(x=0.2, y=net.prop$meanT_FL[i], pch=-9658, cex=1)

plotfunctions::gradientLegend(valRange=c(-2.2,1.6), pos=0.5, inside=F, depth=0.3, length=1, n.seg=0, color=myfun(381), border.col='grey')
segments(x0=rep(1.75,5), x1=rep(2.05,5), y0=c(-2,-1,0,1))
text(x=1.9, y=c(-2,-1,0,1), c(-2,-1,0,1), pos=4, cex=0.75)
points(x=0.9, y=net.prop$meanT_TH[i], pch=-9658, cex=1)






